use crate::client::{JiraCommand, JiraRequestType};
use crate::entities::issue::JiraIssue;

#[derive(Debug)]
pub struct IssueGetCommand {
    pub key: String,
}

impl IssueGetCommand {
    pub fn new(key: &str) -> Self {
        Self {
            key: key.to_string(),
        }
    }
}

impl JiraCommand for IssueGetCommand {
    type TResponse = JiraIssue;
    type TPayload = ();
    const REQUEST_TYPE: JiraRequestType = JiraRequestType::Read;

    fn endpoint(&self) -> String {
        format!("/rest/api/2/issue/{}", self.key)
    }

    fn request_body(&self) -> Option<&Self::TPayload> {
        None
    }

    fn query_params(&self) -> Option<Vec<(String, String)>> {
        None
    }
}
