use crate::client::{JiraCommand, JiraRequestType};
use crate::entities::transitions::Transitions;

#[derive(Debug)]
pub struct IssueTransitionsCommand {
    issue_key: String,
}

impl IssueTransitionsCommand {
    pub fn new(issue_key: &str) -> Self {
        Self {
            issue_key: issue_key.to_string(),
        }
    }
}

impl JiraCommand for IssueTransitionsCommand {
    type TResponse = Transitions;
    type TPayload = ();
    const REQUEST_TYPE: JiraRequestType = JiraRequestType::Read;

    fn endpoint(&self) -> String {
        format!("/rest/api/3/issue/{}/transitions", self.issue_key)
    }

    fn request_body(&self) -> Option<&Self::TPayload> {
        None
    }

    fn query_params(&self) -> Option<Vec<(String, String)>> {
        None
    }
}
